@@ -3,6 +3,11 @@ from scripts.sirene import search_sirene_company
 import os
 import pynsee
 from pynsee import init_conn
+from pynsee.utils import clear_all_cache
+from dotenv import load_dotenv
+
+load_dotenv()
+init_conn(sirene_key=os.getenv("API_KEY"))
 
 def run():
     app = FastMCP("insee-server")
@@ -31,5 +36,7 @@ def run():
     app.run(transport="streamable-http", host="127.0.0.1", port=9000, path="/mcp")
 
 if __name__ == "__main__":
-    init_conn(sirene_key=os.environ["API_KEY"])
+    clear_all_cache()
+    print("API_KEY:", os.getenv("API_KEY"))
+    
     run()
